0.9.9 API documentation: vector_double4_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_double4_precision.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/setup.hpp"
6 #include "../detail/type_vec4.hpp"
7
8 namespace glm
9 {
12
18 typedef vec<4, double, highp> highp_dvec4;
19
25 typedef vec<4, double, mediump> mediump_dvec4;
26
32 typedef vec<4, double, lowp> lowp_dvec4;
33
35 }//namespace glm
glm::mediump_dvec4
vec< 4, double, mediump > mediump_dvec4
4 components vector of medium double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:25
glm::highp_dvec4
vec< 4, double, highp > highp_dvec4
4 components vector of high double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:18
glm::lowp_dvec4
vec< 4, double, lowp > lowp_dvec4
4 components vector of low double-qualifier floating-point numbers.
Definition: vector_double4_precision.hpp:32
glm
Definition: common.hpp:20